@@ -4,6 +4,8 @@ use warnings;
 use base 'SOAP::WSDL::Client';
 use Scalar::Util qw(blessed);
 
+our $VERSION = '2.00_17';
+
 sub call {
     my ($self, $method, $body, $header) = @_;
     if (not blessed $body) {
@@ -23,28 +25,29 @@ sub call {
     return $self->SUPER::call($method, $body, $header);  
 }
 
-sub __create_new {
-  my ($package, %args_of) = @_;
-  
-  no strict qw(refs);
-  
-  # TODO factor out and replace by generated START method
-  *{ "$package\::new" } = sub {
-      my $class = shift;
-      my $self = $class->SUPER::new({
-          proxy => $args_of{ proxy },
-          class_resolver => $args_of{ class_resolver }
-      });
-      bless $self, $class;
-      return $self;
-  }
-}
+#sub __create_new {
+#  my ($package, %args_of) = @_;
+#  
+#  no strict qw(refs);
+#  no warnings qw(redefine);
+#  
+#  # TODO factor out and replace by generated START method
+#  *{ "$package\::new" } = sub {
+#      my $class = shift;
+#      my $self = $class->SUPER::new({
+#          proxy => $args_of{ proxy },
+#          class_resolver => $args_of{ class_resolver }
+#      });
+#      bless $self, $class;
+#      return $self;
+#  }
+#}
 
 sub __create_methods {
   my ($package, %info_of) = @_;
   
   no strict qw(refs);
-  
+  no warnings qw(redefine);  
   for my $method (keys %info_of){
       my ($soap_action, @parts); 
       
@@ -113,9 +116,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 283 $
+ $Rev: 303 $
  $LastChangedBy: kutterma $
- $Id: Base.pm 283 2007-09-27 19:06:29Z kutterma $
+ $Id: Base.pm 303 2007-10-01 18:51:50Z kutterma $
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Client/Base.pm $
  
 =cut
