@@ -210,7 +210,7 @@ sub visit_XSD_ComplexType {
     # TODO is this allowed ? or should we better die ?
     return if not $content_model; # empty complexType
 
-    if ( grep { $_ eq $content_model} qw(all sequence) )
+    if ( grep { $_ eq $content_model} qw(all sequence choice) )
     {
         # visit child elements
         for (@{ $type->get_element() }) {
