@@ -1,11 +1,9 @@
 package SOAP::WSDL::Port;
 use strict;
 use warnings;
-use Class::Std::Fast::Storable;
+use Class::Std::Storable;
 use base qw(SOAP::WSDL::Base);
 
-use version; our $VERSION = qv('2.00.10');
-
 my %binding_of :ATTR(:name<binding> :default<()>);
 my %address_of :ATTR(:name<address> :default<()>);
 
