@@ -2,7 +2,8 @@ package SOAP::WSDL::SOAP::Typelib::Fault11;
 use strict;
 use warnings;
 use Class::Std::Storable;
-use Data::Dumper;
+
+our $VERSION='2.00_17';
 
 use SOAP::WSDL::XSD::Typelib::ComplexType;
 use SOAP::WSDL::XSD::Typelib::Element;
@@ -17,9 +18,6 @@ my %faultstring_of :ATTR(:get<faultstring>);
 my %faultactor_of :ATTR(:get<faultactor>);
 my %detail_of :ATTR(:get<detail>);
 
-# always return false in boolean context - a fault is never true...
-sub as_bool :BOOLIFY { return; }
-
 __PACKAGE__->_factory(
     [ qw(faultcode faultstring faultactor detail) ],
     {
@@ -44,6 +42,10 @@ __PACKAGE__->__set_minOccurs();
 __PACKAGE__->__set_maxOccurs();
 __PACKAGE__->__set_ref('');
 
+# always return false in boolean context - a fault is never true...
+sub as_bool : BOOLIFY { return; }
+
+
 1;
 
 =pod
